@@ -1,6 +1,6 @@
 // info.cpp
 
-// Copyright (C) 2012-2015 by Werner Lemberg.
+// Copyright (C) 2012-2016 by Werner Lemberg.
 //
 // This file is part of the ttfautohint library, and may only be used,
 // modified, and distributed under the terms given in `COPYING'.  By
@@ -103,6 +103,14 @@ build_version_string(Info_Data* idata)
     d = sdscatprintf(d, " -m \"%s\"", bn ? bn : idata->control_name);
     free(bn);
   }
+  if (idata->reference_name)
+  {
+    char* bn = base_name(idata->reference_name);
+    d = sdscatprintf(d, " -R \"%s\"", bn ? bn : idata->reference_name);
+    free(bn);
+
+    d = sdscatprintf(d, " -Z %d", idata->reference_index);
+  }
 
   count = 0;
   strong[0] = '\0';
@@ -128,6 +136,8 @@ build_version_string(Info_Data* idata)
     d = sdscat(d, " -c");
   if (idata->symbol)
     d = sdscat(d, " -s");
+  if (idata->fallback_scaling)
+    d = sdscat(d, " -S");
   if (idata->TTFA_info)
     d = sdscat(d, " -t");
 
@@ -633,7 +643,7 @@ info_post(void* user)
       *(fps++) = c;
   }
   // set correct size
-  sdsIncrLen(family_ps_suffix, fps - family_ps_suffix);
+  sdsIncrLen(family_ps_suffix, (int)(fps - family_ps_suffix));
 
   size_t family_ps_suffix_len = sdslen(family_ps_suffix);
 
@@ -789,7 +799,7 @@ info_post(void* user)
       }
     }
     // set correct size
-    sdsIncrLen(family_ps_name, fpn - family_ps_name);
+    sdsIncrLen(family_ps_name, (int)(fpn - family_ps_name));
 
     sds ps_suffix = is_wide ? family_ps_suffix_wide : family_ps_suffix;
     insert_suffix(ps_suffix,
