@@ -1,6 +1,6 @@
 // maingui.h
 
-// Copyright (C) 2012-2015 by Werner Lemberg.
+// Copyright (C) 2012-2016 by Werner Lemberg.
 //
 // This file is part of the ttfautohint library, and may only be used,
 // modified, and distributed under the terms given in `COPYING'.  By
@@ -11,12 +11,30 @@
 // with the ttfautohint library.
 
 
-#ifndef __MAINGUI_H__
-#define __MAINGUI_H__
+#ifndef MAINGUI_H_
+#define MAINGUI_H_
 
 #include <config.h>
 
-#include <QtGui>
+#include <QAction>
+#include <QCheckBox>
+#include <QComboBox>
+#include <QCompleter>
+#include <QDateTime>
+#include <QDesktopWidget>
+#include <QFileDialog>
+#include <QFileSystemModel>
+#include <QFileSystemWatcher>
+#include <QGridLayout>
+#include <QLabel>
+#include <QMainWindow>
+#include <QMenuBar>
+#include <QMessageBox>
+#include <QProgressDialog>
+#include <QPushButton>
+#include <QSpinBox>
+#include <QStatusBar>
+
 #include "ddlineedit.h"
 #include "ttlineedit.h"
 
@@ -51,8 +69,8 @@ public:
            const char*, int,
            bool, bool, bool,
            bool, bool, bool,
-           const char*, const char*, const char*,
-           bool, bool, bool);
+           const char*, const char*, bool,
+           const char*, bool, bool, bool);
   ~Main_GUI();
 
 protected:
@@ -63,19 +81,23 @@ private slots:
   void browse_input();
   void browse_output();
   void browse_control();
+  void browse_reference();
   void check_min();
   void check_max();
   void check_limit();
   void check_dehint();
   void check_no_limit();
-  void check_no_increase();
+  void check_no_x_increase();
   void check_default_stem_width();
   void absolute_input();
   void absolute_output();
   void absolute_control();
+  void absolute_reference();
+  void set_ref_idx_box_max();
   void check_number_set();
   void check_family_suffix();
   void clear_status_bar();
+  void start_timer();
   void check_watch();
   void watch_files();
   void check_run();
@@ -100,20 +122,38 @@ private:
   int detailed_info;
   int default_script_idx;
   int fallback_script_idx;
+  int fallback_scaling;
   QString family_suffix;
+  int reference_index;
   int symbol;
   int dehint;
   int TTFA_info;
 
+  const int fallback_do_scale;
+  const int fallback_do_hint;
+
+  int latn_script_idx;
+  int none_script_idx;
+
   void create_layout(bool);
   void create_horizontal_layout();
   void create_vertical_layout();
 
+  enum CheckState {
+    DoCheck,
+    CheckNow,
+    CheckLater
+  };
+
+  QFileSystemWatcher* file_watcher;
   QTimer* timer;
   QFileInfo fileinfo_input_file;
   QFileInfo fileinfo_control_file;
+  QFileInfo fileinfo_reference_file;
   QDateTime datetime_input_file;
   QDateTime datetime_control_file;
+  QDateTime datetime_reference_file;
+  CheckState check;
 
   void create_connections();
   void create_actions();
@@ -124,13 +164,17 @@ private:
   void write_settings();
 
   int check_filenames(const QString&,
+                      const QString&,
                       const QString&,
                       const QString&);
   int open_files(const QString&, FILE**,
+                 const QString&, FILE**,
                  const QString&, FILE**,
                  const QString&, FILE**);
   int handle_error(TA_Error, const unsigned char*, QString);
 
+  void stop_watching();
+
   QMenu* file_menu;
   QMenu* help_menu;
 
@@ -146,6 +190,13 @@ private:
   Drag_Drop_Line_Edit* control_line;
   QPushButton* control_button;
 
+  QLabel* reference_label;
+  Drag_Drop_Line_Edit* reference_line;
+  QPushButton* reference_button;
+
+  QLabel* ref_idx_label;
+  QSpinBox* ref_idx_box;
+
   QLabel* min_label;
   QSpinBox* min_box;
   QLabel* max_label;
@@ -160,6 +211,7 @@ private:
   QComboBox* default_box;
   QLabel* fallback_label;
   QComboBox* fallback_box;
+  QComboBox* fallback_hint_or_scale_box;
 
   QLabel* limit_label;
   QString limit_label_text_with_key;
@@ -169,13 +221,13 @@ private:
   QString no_limit_box_text_with_key;
   QString no_limit_box_text;
 
-  QLabel* increase_label;
-  QString increase_label_text_with_key;
-  QString increase_label_text;
-  QSpinBox* increase_box;
-  QCheckBox* no_increase_box;
-  QString no_increase_box_text_with_key;
-  QString no_increase_box_text;
+  QLabel* x_increase_label;
+  QString x_increase_label_text_with_key;
+  QString x_increase_label_text;
+  QSpinBox* x_increase_box;
+  QCheckBox* no_x_increase_box;
+  QString no_x_increase_box_text_with_key;
+  QString no_x_increase_box_text;
 
   QLabel* snapping_label;
   Tooltip_Line_Edit* snapping_line;
@@ -209,6 +261,6 @@ private:
   QLocale* locale;
 };
 
-#endif // __MAINGUI_H__
+#endif // MAINGUI_H_
 
 // end of maingui.h
