@@ -1,6 +1,6 @@
 // ttlineedit.h
 
-// Copyright (C) 2012-2014 by Werner Lemberg.
+// Copyright (C) 2012-2016 by Werner Lemberg.
 //
 // This file is part of the ttfautohint library, and may only be used,
 // modified, and distributed under the terms given in `COPYING'.  By
@@ -11,12 +11,12 @@
 // with the ttfautohint library.
 
 
-#ifndef __TTLINEEDIT_H__
-#define __TTLINEEDIT_H__
+#ifndef TTLINEEDIT_H_
+#define TTLINEEDIT_H_
 
 #include <config.h>
 
-#include <QtGui>
+#include <QLineEdit>
 
 class Tooltip_Line_Edit
 : public QLineEdit
@@ -31,6 +31,6 @@ public slots:
 };
 
 
-#endif // __TTLINEEDIT_H__
+#endif // TTLINEEDIT_H_
 
 // end of ttlineedit.h
