@@ -1,7 +1,7 @@
 /* numberset.h */
 
 /*
- * Copyright (C) 2012-2015 by Werner Lemberg.
+ * Copyright (C) 2012-2016 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -13,8 +13,8 @@
  */
 
 
-#ifndef __NUMBERSET_H__
-#define __NUMBERSET_H__
+#ifndef NUMBERSET_H_
+#define NUMBERSET_H_
 
 #ifdef __cplusplus
 extern "C" {
@@ -228,6 +228,6 @@ number_set_get_next(number_set_iter* iter_p);
 } /* extern "C" */
 #endif
 
-#endif /* __NUMBERSET_H__ */
+#endif /* NUMBERSET_H_ */
 
 /* end of numberset.h */
