@@ -52,13 +52,13 @@
 /* utility macros to get data from a pointer (with auto-increment) */
 
 #define NEXT_USHORT(buffer) \
-          ((FT_UShort)(buffer += 2, buffer[-2] << 8 \
-                                    | buffer[-1]))
+          ((FT_UShort)(buffer += 2, (FT_UShort)buffer[-2] << 8 \
+                                    | (FT_UShort)buffer[-1]))
 #define NEXT_ULONG(buffer) \
-          ((FT_ULong)(buffer += 4, buffer[-4] << 24 \
-                                   | buffer[-3] << 16 \
-                                   | buffer[-2] << 8 \
-                                   | buffer[-1]))
+          ((FT_ULong)(buffer += 4, (FT_ULong)buffer[-4] << 24 \
+                                   | (FT_ULong)buffer[-3] << 16 \
+                                   | (FT_ULong)buffer[-2] << 8 \
+                                   | (FT_ULong)buffer[-1]))
 
 
 /* an SFNT tag for our information table */
@@ -232,6 +232,13 @@ struct FONT_
   char* control_buf;
   size_t control_len;
 
+  FT_Byte* reference_buf;
+  size_t reference_len;
+
+  FT_Face reference;
+  FT_Long reference_index;
+  const char* reference_name;
+
   SFNT* sfnts;
   FT_Long num_sfnts;
 
@@ -277,11 +284,13 @@ struct FONT_
   FT_Bool hint_composites;
   FT_Bool ignore_restrictions;
   TA_Style fallback_style;
+  FT_Bool fallback_scaling;
   TA_Script default_script;
   FT_Bool symbol;
   FT_Bool dehint;
   FT_Bool debug;
   FT_Bool TTFA_info;
+  unsigned long long epoch;
 };
 
 
@@ -303,7 +312,8 @@ TA_font_dump_parameters(FONT* font,
                         FT_Bool format);
 
 void
-TA_get_current_time(FT_ULong* high,
+TA_get_current_time(FONT* font,
+                    FT_ULong* high,
                     FT_ULong* low);
 
 FT_Byte*
@@ -319,11 +329,13 @@ void
 TA_font_unload(FONT* font,
                const char* in_buf,
                char** out_bufp,
-               const char* control_buf);
+               const char* control_buf,
+               const char* reference_buf);
 
 FT_Error
-TA_font_file_read(FONT* font,
-                  FILE* in_file);
+TA_font_file_read(FILE* file,
+                  FT_Byte** buffer,
+                  size_t* length);
 FT_Error
 TA_font_file_write(FONT* font,
                    FILE* out_file);
