@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Skeleton interface for Bison GLR parsers in C
 
-   Copyright (C) 2002-2013 Free Software Foundation, Inc.
+   Copyright (C) 2002-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,15 +40,15 @@
 extern int TA_control_debug;
 #endif
 /* "%code requires" blocks.  */
-#line 46 "tacontrol.bison" /* glr.c:2555  */
+#line 46 "./tacontrol.bison" /* glr.c:197  */
 
 #include "ta.h"
-#include "taharfbuzz.h"
+#include "tashaper.h"
 
 /* we don't change the name prefix of flex functions */
 #define TA_control_lex yylex
 
-#line 52 "tacontrol-bison.h" /* glr.c:2555  */
+#line 52 "tacontrol-bison.h" /* glr.c:197  */
 
 /* Token type.  */
 #ifndef YYTOKENTYPE
@@ -73,10 +73,10 @@ extern int TA_control_debug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE YYSTYPE;
+
 union YYSTYPE
 {
-#line 54 "tacontrol.bison" /* glr.c:2555  */
+#line 54 "./tacontrol.bison" /* glr.c:197  */
 
   char character;
   Control_Type type;
@@ -86,8 +86,10 @@ union YYSTYPE
   double real;
   Control* control;
 
-#line 90 "tacontrol-bison.h" /* glr.c:2555  */
+#line 90 "tacontrol-bison.h" /* glr.c:197  */
 };
+
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
 #endif
