@@ -1,7 +1,7 @@
 /* tadump.c */
 
 /*
- * Copyright (C) 2014-2015 by Werner Lemberg.
+ * Copyright (C) 2014-2016 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -64,11 +64,12 @@ TA_font_dump_parameters(FONT* font,
   if (format)
   {
     s = sdscat(s, "TTF_autohint parameters\n"
-                  "=======================\n"
-                  "\n");
+                  "=======================\n");
     width = 33;
   }
 
+  s = sdscat(s, "\n");
+
   if (font->dehint)
   {
     if (format)
@@ -83,6 +84,8 @@ TA_font_dump_parameters(FONT* font,
           script_names[font->default_script]);
   DUMPVAL("dw-cleartype-strong-stem-width",
           font->dw_cleartype_strong_stem_width);
+  DUMPVAL("fallback-scaling",
+          font->fallback_scaling);
   DUMPSTR("fallback-script",
           script_names[ta_style_classes[font->fallback_style]->script]);
   DUMPVAL("fallback-stem-width",
@@ -103,6 +106,17 @@ TA_font_dump_parameters(FONT* font,
           font->ignore_restrictions);
   DUMPVAL("increase-x-height",
           font->increase_x_height);
+  if (font->reference_name)
+    DUMPSTR("reference",
+            font->reference_name);
+  else if (font->reference_buf)
+    DUMPSTR("reference",
+            "<yes>");
+  else
+    DUMPSTR("reference",
+            "");
+  DUMPVAL("reference-index",
+          font->reference_index);
   DUMPVAL("symbol",
           font->symbol);
   DUMPVAL("TTFA-info",
@@ -129,13 +143,6 @@ TA_font_dump_parameters(FONT* font,
     goto Exit;
   }
 
-  /* show control instructions line by line */
-  if (!format)
-  {
-    eol = "";
-    prev_eol = "; \\\n";
-  }
-
   if (*ds)
   {
     char* token;
@@ -143,7 +150,16 @@ TA_font_dump_parameters(FONT* font,
 
 
     token = strtok_r(ds, "\n", &saveptr);
-    DUMPSTR("control-instructions", token);
+    if (format)
+      DUMPSTR("control-instructions", token);
+    else
+    {
+      DUMPSTR("control-instructions", "\\");
+      eol = "";
+      /* show control instructions line by line */
+      DUMPSTRX(token);
+      prev_eol = "; \\\n";
+    }
 
     for (;;)
     {
