@@ -1,7 +1,7 @@
 /* tafeature.c */
 
 /*
- * Copyright (C) 2015 by Werner Lemberg.
+ * Copyright (C) 2015-2016 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -12,7 +12,7 @@
  * with the ttfautohint library.
  */
 
-#include "taharfbuzz.h"
+#include "tashaper.h"
 
 
 #undef COVERAGE
