@@ -1,7 +1,7 @@
 /* tastyles.h */
 
 /*
- * Copyright (C) 2014-2015 by Werner Lemberg.
+ * Copyright (C) 2014-2016 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -31,7 +31,7 @@
  *
  * Note that styles using `TA_COVERAGE_DEFAULT' should always
  * come after styles with other coverages.  Also note that
- * fallback scripts only use `AF_COVERAGE_DEFAULT' for its
+ * fallback scripts only use `TA_COVERAGE_DEFAULT' for its
  * style.
  *
  * Example:
@@ -94,6 +94,27 @@ STYLE(arab_dflt, ARAB_DFLT,
       TA_BLUE_STRINGSET_ARAB,
       TA_COVERAGE_DEFAULT)
 
+STYLE(armn_dflt, ARMN_DFLT,
+      "Armenian default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_ARMN,
+      TA_BLUE_STRINGSET_ARMN,
+      TA_COVERAGE_DEFAULT)
+
+STYLE(beng_dflt, BENG_DFLT,
+      "Bengali default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_BENG,
+      TA_BLUE_STRINGSET_BENG,
+      TA_COVERAGE_DEFAULT)
+
+STYLE(cher_dflt, CHER_DFLT,
+      "Cherokee default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_CHER,
+      TA_BLUE_STRINGSET_CHER,
+      TA_COVERAGE_DEFAULT)
+
 META_STYLE_LATIN(cyrl, CYRL, "Cyrillic")
 
 STYLE(deva_dflt, DEVA_DFLT,
@@ -103,8 +124,43 @@ STYLE(deva_dflt, DEVA_DFLT,
       TA_BLUE_STRINGSET_DEVA,
       TA_COVERAGE_DEFAULT)
 
+STYLE(ethi_dflt, ETHI_DFLT,
+      "Ethiopic default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_ETHI,
+      TA_BLUE_STRINGSET_ETHI,
+      TA_COVERAGE_DEFAULT)
+
+STYLE(geor_dflt, GEOR_DFLT,
+      "Georgian (Mkhedruli) default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_GEOR,
+      TA_BLUE_STRINGSET_GEOR,
+      TA_COVERAGE_DEFAULT)
+
+STYLE(geok_dflt, GEOK_DFLT,
+      "Georgian (Khutsuri) default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_GEOK,
+      TA_BLUE_STRINGSET_GEOK,
+      TA_COVERAGE_DEFAULT)
+
 META_STYLE_LATIN(grek, GREK, "Greek")
 
+STYLE(gujr_dflt, GUJR_DFLT,
+      "Gujarati default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_GUJR,
+      TA_BLUE_STRINGSET_GUJR,
+      TA_COVERAGE_DEFAULT)
+
+STYLE(guru_dflt, GURU_DFLT,
+      "Gurmukhi default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_GURU,
+      TA_BLUE_STRINGSET_GURU,
+      TA_COVERAGE_DEFAULT)
+
 STYLE(hebr_dflt, HEBR_DFLT,
       "Hebrew default style",
       TA_WRITING_SYSTEM_LATIN,
@@ -112,6 +168,27 @@ STYLE(hebr_dflt, HEBR_DFLT,
       TA_BLUE_STRINGSET_HEBR,
       TA_COVERAGE_DEFAULT)
 
+STYLE(knda_dflt, KNDA_DFLT,
+      "Kannada default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_KNDA,
+      TA_BLUE_STRINGSET_KNDA,
+      TA_COVERAGE_DEFAULT)
+
+STYLE(khmr_dflt, KHMR_DFLT,
+      "Khmer default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_KHMR,
+      TA_BLUE_STRINGSET_KHMR,
+      TA_COVERAGE_DEFAULT)
+
+STYLE(khms_dflt, KHMS_DFLT,
+      "Khmer Symbols default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_KHMS,
+      TA_BLUE_STRINGSET_KHMS,
+      TA_COVERAGE_DEFAULT)
+
 STYLE(lao_dflt, LAO_DFLT,
       "Lao default style",
       TA_WRITING_SYSTEM_LATIN,
@@ -144,6 +221,34 @@ STYLE(ltn2_dflt, LTN2_DFLT,
       TA_COVERAGE_DEFAULT)
 #endif
 
+STYLE(mlym_dflt, MLYM_DFLT,
+      "Malayalam default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_MLYM,
+      TA_BLUE_STRINGSET_MLYM,
+      TA_COVERAGE_DEFAULT)
+
+STYLE(mymr_dflt, MYMR_DFLT,
+      "Myanmar default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_MYMR,
+      TA_BLUE_STRINGSET_MYMR,
+      TA_COVERAGE_DEFAULT)
+
+STYLE(sinh_dflt, SINH_DFLT,
+      "Sinhala default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_SINH,
+      TA_BLUE_STRINGSET_SINH,
+      TA_COVERAGE_DEFAULT)
+
+STYLE(taml_dflt, TAML_DFLT,
+      "Tamil default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_TAML,
+      TA_BLUE_STRINGSET_TAML,
+      TA_COVERAGE_DEFAULT)
+
 STYLE(telu_dflt, TELU_DFLT,
       "Telugu default style",
       TA_WRITING_SYSTEM_LATIN,
@@ -160,9 +265,9 @@ STYLE(thai_dflt, THAI_DFLT,
 
 STYLE(none_dflt, NONE_DFLT,
       "no style",
-      TA_WRITING_SYSTEM_DUMMY,
+      TA_WRITING_SYSTEM_LATIN,
       TA_SCRIPT_NONE,
-      (TA_Blue_Stringset)0,
+      TA_BLUE_STRINGSET_NONE,
       TA_COVERAGE_DEFAULT)
 
 /* end of tastyles.h */
