@@ -1,7 +1,7 @@
 /* tattf.c */
 
 /*
- * Copyright (C) 2011-2015 by Werner Lemberg.
+ * Copyright (C) 2011-2016 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -126,8 +126,14 @@ TA_sfnt_build_TTF_header(SFNT* sfnt,
       head_buf[10] = 0x00;
       head_buf[11] = 0x00;
 
+      /* update flags; we have to */
+      /* set bit 2 (`instructions may depend on point size') and to */
+      /* clear bit 4 (`instructions may alter advance width') */
+      head_buf[17] |= 0x04U;
+      head_buf[17] &= ~0x10U;
+
       /* update modification time */
-      TA_get_current_time(&date_high, &date_low);
+      TA_get_current_time(font, &date_high, &date_low);
 
       head_buf[28] = BYTE1(date_high);
       head_buf[29] = BYTE2(date_high);
