@@ -1,7 +1,7 @@
 /* tatypes.h */
 
 /*
- * Copyright (C) 2011-2015 by Werner Lemberg.
+ * Copyright (C) 2011-2016 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -17,8 +17,8 @@
 
 /* heavily modified 2011 by Werner Lemberg <wl@gnu.org> */
 
-#ifndef __TATYPES_H__
-#define __TATYPES_H__
+#ifndef TATYPES_H_
+#define TATYPES_H_
 
 #include <ft2build.h>
 
@@ -88,6 +88,9 @@ extern void* _ta_debug_hints;
 #endif /* !TA_DEBUG */
 
 
+#define TA_MIN(a, b) ((a) < (b) ? (a) : (b))
+#define TA_MAX(a, b) ((a) > (b) ? (a) : (b))
+
 #define TA_ABS(a) ((a) < 0 ? -(a) : (a))
 
 /* from file `ftconfig.h' (2015-03-02) from FreeType */
@@ -177,10 +180,12 @@ typedef struct TA_ScalerRec_
 typedef struct TA_StyleMetricsRec_* TA_StyleMetrics;
 
 /* this function parses an FT_Face to compute global metrics */
-/* for a specific style */
+/* for a specific style, optionally using another FT_Face to */
+/* derive blue zones                                         */
 typedef FT_Error
 (*TA_WritingSystem_InitMetricsFunc)(TA_StyleMetrics metrics,
-                                    FT_Face face);
+                                    FT_Face face,
+                                    FT_Face reference);
 typedef void
 (*TA_WritingSystem_ScaleMetricsFunc)(TA_StyleMetrics metrics,
                                      TA_Scaler scaler);
@@ -215,7 +220,7 @@ typedef void
  *   outline according to the results of the glyph analyzer.
  */
 
-#define __TAWRTSYS_H__ /* don't load header files */
+#define TAWRTSYS_H_ /* don't load header files */
 #undef WRITING_SYSTEM
 #define WRITING_SYSTEM(ws, WS) \
           TA_WRITING_SYSTEM_ ## WS,
@@ -228,7 +233,7 @@ typedef enum TA_WritingSystem_
   TA_WRITING_SYSTEM_MAX /* do not remove */
 } TA_WritingSystem;
 
-#undef __TAWRTSYS_H__
+#undef TAWRTSYS_H_
 
 
 typedef struct TA_WritingSystemClassRec_
@@ -257,7 +262,7 @@ typedef const TA_WritingSystemClassRec* TA_WritingSystemClass;
  */
 
 #undef SCRIPT
-#define SCRIPT(s, S, d, h, sc1, sc2, sc3) \
+#define SCRIPT(s, S, d, h, H, ss) \
           TA_SCRIPT_ ## S,
 
 /* The list of known scripts. */
@@ -278,6 +283,9 @@ typedef struct TA_Script_UniRangeRec_
 #define TA_UNIRANGE_REC(a, b) \
           { (FT_UInt32)(a), (FT_UInt32)(b) }
 
+#define TA_HINTING_BOTTOM_TO_TOP 0
+#define TA_HINTING_TOP_TO_BOTTOM 1
+
 typedef const TA_Script_UniRangeRec* TA_Script_UniRange;
 
 typedef struct TA_ScriptClassRec_
@@ -288,9 +296,9 @@ typedef struct TA_ScriptClassRec_
   TA_Script_UniRange script_uni_ranges;
   TA_Script_UniRange script_uni_nonbase_ranges;
 
-  FT_UInt32 standard_char1; /* for default width and height */
-  FT_UInt32 standard_char2; /* ditto */
-  FT_UInt32 standard_char3; /* ditto */
+  FT_Bool top_to_bottom_hinting;
+
+  const char* standard_charstring; /* for default width and height */
 } TA_ScriptClassRec;
 
 typedef const TA_ScriptClassRec* TA_ScriptClass;
@@ -394,6 +402,6 @@ typedef struct TA_StyleMetricsRec_
 } /* extern "C" */
 #endif
 
-#endif /* __TATYPES_H__ */
+#endif /* TATYPES_H_ */
 
 /* end of tatypes.h */
