@@ -38,6 +38,12 @@ SCRIPT(arab, ARAB,
        HINTING_BOTTOM_TO_TOP,
        "\xD9\x84 \xD8\xAD \xD9\x80") /* ل ح ـ */
 
+SCRIPT(armn, ARMN,
+       "Armenian",
+       HB_SCRIPT_ARMENIAN,
+       HINTING_BOTTOM_TO_TOP,
+       "\xD5\xBD \xD5\x8D") /* ս Ս */
+
 /* there are no simple forms for letters; we thus use two digit shapes */
 SCRIPT(beng, BENG,
        "Bengali",
@@ -45,6 +51,12 @@ SCRIPT(beng, BENG,
        HINTING_TOP_TO_BOTTOM,
        "\xE0\xA7\xA6 \xE0\xA7\xAA") /* ০ ৪*/
 
+SCRIPT(cher, CHER,
+       "Cherokee",
+       HB_SCRIPT_CHEROKEE,
+       HINTING_BOTTOM_TO_TOP,
+       "\xE1\x8E\xA4 \xE1\x8F\x85 \xEA\xAE\x95") /* Ꭴ Ꮕ ꮕ */
+
 SCRIPT(cyrl, CYRL,
        "Cyrillic",
        HB_SCRIPT_CYRILLIC,
@@ -57,18 +69,54 @@ SCRIPT(deva, DEVA,
        HINTING_TOP_TO_BOTTOM,
        "\xE0\xA4\xA0 \xE0\xA4\xB5 \xE0\xA4\x9F") /* ठ व ट */
 
+SCRIPT(ethi, ETHI,
+       "Ethiopic",
+       HB_SCRIPT_ETHIOPIC,
+       HINTING_BOTTOM_TO_TOP,
+       "\xE1\x8B\x90") /* ዐ */
+
+SCRIPT(geor, GEOR,
+       "Georgian (Mkhedruli)",
+       HB_SCRIPT_GEORGIAN,
+       HINTING_BOTTOM_TO_TOP,
+       "\xE1\x83\x98 \xE1\x83\x94 \xE1\x83\x90") /* ი ე ა */
+
+SCRIPT(geok, GEOK,
+       "Georgian (Khutsuri)",
+       HB_SCRIPT_INVALID,
+       HINTING_BOTTOM_TO_TOP,
+       "\xE1\x82\xB6 \xE1\x82\xB1 \xE2\xB4\x99") /* Ⴖ Ⴑ ⴙ */
+
 SCRIPT(grek, GREK,
        "Greek",
        HB_SCRIPT_GREEK,
        HINTING_BOTTOM_TO_TOP,
        "\xCE\xBF \xCE\x9F") /* ο Ο */
 
+SCRIPT(gujr, GUJR,
+       "Gujarati",
+       HB_SCRIPT_GUJARATI,
+       HINTING_BOTTOM_TO_TOP,
+       "\xE0\xAA\x9F \xE0\xAB\xA6") /* ટ ૦ */
+
+SCRIPT(guru, GURU,
+       "Gurmukhi",
+       HB_SCRIPT_GURMUKHI,
+       HINTING_TOP_TO_BOTTOM,
+       "\xE0\xA8\xA0 \xE0\xA8\xB0 \xE0\xA9\xA6") /* ਠ ਰ ੦*/
+
 SCRIPT(hebr, HEBR,
        "Hebrew",
        HB_SCRIPT_HEBREW,
        HINTING_BOTTOM_TO_TOP,
        "\xD7\x9D") /* ם */
 
+SCRIPT(knda, KNDA,
+       "Kannada",
+       HB_SCRIPT_KANNADA,
+       HINTING_BOTTOM_TO_TOP,
+       "\xE0\xB3\xA6 \xE0\xB2\xAC") /* ೦ ಬ */
+
 /* only digit zero has a simple shape in the Khmer script */
 SCRIPT(khmr, KHMR,
        "Khmer",
@@ -107,12 +155,31 @@ SCRIPT(latp, LATP,
        HINTING_BOTTOM_TO_TOP,
        "\xE1\xB5\x92 \xE1\xB4\xBC \xE2\x81\xB0") /* ᵒ ᴼ ⁰ */
 
+SCRIPT(mlym, MLYM,
+       "Malayalam",
+       HB_SCRIPT_MALAYALAM,
+       HINTING_BOTTOM_TO_TOP,
+       "\xE0\xB4\xA0 \xE0\xB4\xB1") /* ഠ റ */
+
 SCRIPT(mymr, MYMR,
        "Myanmar",
        HB_SCRIPT_MYANMAR,
        HINTING_BOTTOM_TO_TOP,
        "\xE1\x80\x9D \xE1\x80\x84 \xE1\x80\x82") /* ဝ င ဂ */
 
+SCRIPT(sinh, SINH,
+       "Sinhala",
+       HB_SCRIPT_SINHALA,
+       HINTING_BOTTOM_TO_TOP,
+       "\xE0\xB6\xA7") /* ට */
+
+/* only digit zero has a simple (round) shape in the Tamil script */
+SCRIPT(taml, TAML,
+       "Tamil",
+       HB_SCRIPT_TAMIL,
+       HINTING_BOTTOM_TO_TOP,
+       "\xE0\xAF\xA6") /* ௦ */
+
 /* there are no simple forms for letters; we thus use two digit shapes */
 SCRIPT(telu, TELU,
        "Telugu",
