@@ -1,7 +1,7 @@
 /* ttfautohint.h */
 
 /*
- * Copyright (C) 2011-2015 by Werner Lemberg.
+ * Copyright (C) 2011-2016 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -13,10 +13,11 @@
  */
 
 
-#ifndef __TTFAUTOHINT_H__
-#define __TTFAUTOHINT_H__
+#ifndef TTFAUTOHINT_H_
+#define TTFAUTOHINT_H_
 
 #include <stdarg.h>
+#include <stdint.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -248,7 +249,8 @@ typedef int
  *
  * Read a TrueType font, remove existing bytecode (in the SFNT tables
  * `prep`, `fpgm`, `cvt `, and `glyf`), and write a new TrueType font with
- * new bytecode based on the autohinting of the FreeType library.
+ * new bytecode based on the autohinting of the FreeType library, optionally
+ * using a reference font to derive blue zones.
  *
  * It expects a format string *options* and a variable number of arguments,
  * depending on the fields in *options*.  The fields are comma separated;
@@ -304,6 +306,29 @@ typedef int
  * :   A value of type `size_t`, giving the length of the control
  *     instructions buffer.  Needs `control-buffer`.
  *
+ * `reference-file`
+ * :   A pointer of type `FILE*` to the data stream of the reference font,
+ *     opened for binary reading.  Mutually exclusive with
+ *     `reference-buffer`.
+ *
+ * `reference-buffer`
+ * :   A pointer of type `const char*` to a buffer that contains the
+ *     reference font.  Needs `reference-buffer-len`.  Mutually exclusive
+ *     with `reference-file`.
+ *
+ * `reference-buffer-len`
+ * :   A value of type `size_t`, giving the length of the reference buffer.
+ *     Needs `reference-buffer`.
+ *
+ * `reference-index`
+ * :   The face index to be used in the reference font.  The default value
+ *     is\ 0.
+ *
+ * `reference-name`
+ * :   A string that specifies the name of the reference font.  It is only
+ *     used to emit a sensible value for the `TTFA` table if `TTFA-info` is
+ *     set.
+ *
  *
  * ### Messages and Callbacks
  *
@@ -462,11 +487,22 @@ typedef int
  *     `ttfautohint-scripts.h`.
  *
  * `fallback-script`
- * :   A string consisting of four lowercase characters that specifies the
+ * :   A string consisting of four lowercase characters, specifying the
  *     default script for glyphs that can't be mapped to a script
- *     automatically.  If set to `"none"` (which is the default), no script
- *     is used.  Valid values can be found in the header file
- *     `ttfautohint-scripts.h`.
+ *     automatically.  By default, such glyphs are hinted; if option
+ *     `fallback-scaling` is set, they are scaled only instead.  Valid
+ *     values can be found in the header file `ttfautohint-scripts.h`.
+ *
+ *     Default value is `"none"`, which means hinting without using a
+ *     script's blue zones if `fallback-scaling` isn't set.  If
+ *     `fallback_scaling` is set, value `"none"` implies no hinting for
+ *     unmapped glyphs.
+ *
+ * `fallback-scaling`
+ * :   Set this integer to\ 1 if glyphs handled by the fallback script
+ *     should be scaled only with the fallback script's scaling value,
+ *     instead of being hinted with the fallback script's hinting
+ *     parameters.
  *
  * `symbol`
  * :   Set this integer to\ 1 if you want to process a font that ttfautohint
@@ -524,6 +560,14 @@ typedef int
  * :   If set to\ 1, remove all hints from the font.  All other hinting
  *     options are ignored.
  *
+ * `epoch`
+ * :   An integer of type `unsigned long long`, defined as the number of
+ *     seconds (excluding leap seconds) since 01 Jan 1970 00:00:00 UTC.  If
+ *     set, or if the value is not equal to `ULLONG_MAX`, this epoch gets
+ *     used instead of the current date and time for the 'modification time'
+ *     field in the TTF header.  Use this to get [reproducible
+ *     builds](https://reproducible-builds.org/).
+ *
  *
  * ### Remarks
  *
@@ -563,6 +607,6 @@ TTF_autohint(const char* options,
 } /* extern "C" */
 #endif
 
-#endif /* __TTFAUTOHINT_H__ */
+#endif /* TTFAUTOHINT_H_ */
 
 /* end of ttfautohint.h */
